@@ -23,7 +23,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "knumber_error.h"
 #include <QScopedArrayPointer>
 #include <QDebug>
+#if defined(Q_OS_MAC) || defined(Q_OS_OPENBSD)
+#include <math.h>
+#else
 #include <cmath>
+#endif
 
 // NOTE: these assume IEEE floats..
 #ifndef HAVE_FUNC_ISINF
@@ -900,7 +904,7 @@ knumber_base *knumber_float::exp10() {
 		delete this;
 		return new knumber_error(knumber_error::ERROR_POS_INFINITY);
 	} else {
-		return execute_libc_func< ::exp10>(x);
+		return execute_libc_func< ::pow>(10, x);
 	}
 #endif
 }
